#
# spec file for package python-jsondiff
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without libalternatives
%{?sle15_python_module_pythons}
Name:           python-jsondiff
Version:        2.2.1
Release:        2.1
Summary:        Module to diff JSON and JSON-like structures in Python
License:        MIT
URL:            https://github.com/ZoomerAnalytics/jsondiff
Source:         https://files.pythonhosted.org/packages/source/j/jsondiff/jsondiff-%{version}.tar.gz
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wheel}
BuildRequires:  alts
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       alts
Requires:       python-PyYAML
BuildArch:      noarch
%python_subpackages

%description
Package to show differences between JSON and JSON-like structures in Python

%prep
%autosetup -p1 -n jsondiff-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/jdiff
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%pre
%python_libalternatives_reset_alternative jdiff

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/jsondiff
%{python_sitelib}/jsondiff-%{version}.dist-info
%python_alternative %{_bindir}/jdiff

%changelog
* Thu Jul 10 2025 Markéta Machová <mmachova@suse.com>
- Convert to libalternatives
* Thu Oct 10 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.2.1
  * Protect Symbol.eq by instance check
* Tue Aug 13 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.2.0:
  * Exclude a list of paths from diff.
  * really drop python<=3.7 support
  * remove last bits of python2 support
  * Fix pypi release readme formatting
  * Minimal conversion to pytest+hypothesis
  * Added simple equality operator for class Symbol
  * jsondiff: fix symbol equality
  * setup.py: migrate to pyproject.toml
  * fix: better diffing of empty containers
  * add rightonly jsondiff syntax
  * Introduce YAML support
  * packaging: revert to requirements files
- Switch back to PyPi tarball. (required for setuptools_scm)
- Drop patch remove_nose.patch, no longer required.
* Tue Mar 26 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
- Limit Python files matched in %%files section
* Tue Jun 13 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Tue May 24 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 2.0.0
  * Removed deprecated function
  * Remove deprecated jsondiff entry point
- from version 1.3.1
  * Optionally allow different escape_str than '$'
  * Clarified the readme, closes #23
  * Fixed readme
- Remove jsondiff command from %%install, %%post, %%postun and %%files sections
* Tue Dec  7 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 1.3.0
  * Update README.rst
  * Add license to setup.py
  * Upating travis config to explicitly set ubuntu versions to use
    for each python version.
  * Fix long list diffing bug by converting recursive code to iterative.
  * Add failing test for list-diff recursion error bug
- Refresh patches for new version
  * remove_nose.patch
- Switch Source field to point to Github tarball URL
  * The tarball from PyPi does not contain the tests
* Sun Sep 13 2020 Matej Cepl <mcepl@suse.com>
- Add remove_nose.patch to remove requirement for nose.
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Oct  4 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 1.2.0
  * Deprecate the jsondiff command due to conflicts with json-patch
* Sun Jun  2 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Fri May 17 2019 Scott Wulf <swulf@suse.com>
- Removing conflict with jsonpatch
  * Reasoning:
  - moto requires cfn-lint and jsondiff
  - cfn-lint requires jsonpatch
* Tue May 14 2019 Gary Smith <GSmith@suse.com>
- Upgraded to 1.1.2
  * no changelog available
* Mon May 14 2018 tchvatal@suse.com
- Conflict with python-jsonpatch
* Wed May  9 2018 toddrme2178@gmail.com
- Fix typo to allow building
* Tue May  8 2018 tchvatal@suse.com
- Initial commit, required by python-moto
